summaryrefslogtreecommitdiffstats
path: root/kompare/libdialogpages/pagebase.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:38 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:38 -0600
commitd6331f1b56eb6dca7a1950658b2932f208015da0 (patch)
treef99bf8d1571f93304bdb4a46fb199a1bde60e6ee /kompare/libdialogpages/pagebase.cpp
parente738fee8847c1f606df7b338a589cc8c0539a521 (diff)
downloadtdesdk-d6331f1b56eb6dca7a1950658b2932f208015da0.tar.gz
tdesdk-d6331f1b56eb6dca7a1950658b2932f208015da0.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kompare/libdialogpages/pagebase.cpp')
-rw-r--r--kompare/libdialogpages/pagebase.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kompare/libdialogpages/pagebase.cpp b/kompare/libdialogpages/pagebase.cpp
index 33c45dba..3a35e479 100644
--- a/kompare/libdialogpages/pagebase.cpp
+++ b/kompare/libdialogpages/pagebase.cpp
@@ -17,7 +17,7 @@
**
***************************************************************************/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqobjectlist.h>
#include "pagebase.h"
@@ -36,9 +36,9 @@ PageBase::~PageBase()
TQSize PageBase::sizeHintForWidget( TQWidget* widget )
{
//
// The size is computed by adding the tqsizeHint().height() of all
// widget tqchildren and taking the width of the widest child and adding
// tqlayout()->margin() and tqlayout()->spacing()
//
// this code in this method has been ripped out of a file in kbabel
@@ -57,7 +57,7 @@ TQSize PageBase::sizeHintForWidget( TQWidget* widget )
numChild += 1;
TQWidget *w=((TQWidget*)o);
- TQSize s = w->tqsizeHint();
+ TQSize s = w->sizeHint();
if( s.isEmpty() == true )
{
s = TQSize( 50, 100 ); // Default size
@@ -72,8 +72,8 @@ TQSize PageBase::sizeHintForWidget( TQWidget* widget )
if( numChild > 0 )
{
- size.setHeight( size.height() + widget->tqlayout()->spacing()*(numChild-1) );
- size += TQSize( widget->tqlayout()->margin()*2, widget->tqlayout()->margin()*2 + 1 );
+ size.setHeight( size.height() + widget->layout()->spacing()*(numChild-1) );
+ size += TQSize( widget->layout()->margin()*2, widget->layout()->margin()*2 + 1 );
}
else
{
@@ -36,9 +36,9 @@ PageBase::~PageBase()
{
//
- // The size is computed by adding the tqsizeHint().height() of all
- // widget tqchildren and taking the width of the widest child and adding
- // tqlayout()->margin() and tqlayout()->spacing()
+ // The size is computed by adding the sizeHint().height() of all
+ // widget children and taking the width of the widest child and adding
+ // layout()->margin() and layout()->spacing()
//
// this code in this method has been ripped out of a file in kbabel